#!/bin/ksh
#

########################################################
# set paths and files

MODULE="LuUTRAN"
RELEASE="6.0.9.1.0"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarDir=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################

# Check env settings
 echo "Checking environment....."

  if ! [[ -d ${FLEXPM_HOME} ]]; then
     echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
     exit;
  fi

  if ! [[ -d ${FLEXPM_BASE} ]]; then
     echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
     exit;
  fi

  if [ -z ${DB_CONNECT} ]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit 1;
  fi

  ###### module variable validation
  if ! [[ -d ${LuUTRAN_HOME} ]]; then
     echo "Env variable LuUTRAN_HOME must be set to appropriate dir before installation."
     exit;
  fi

    #######################################################
    # Installing module...
    #######################################################

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $FLEXPM_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarDir $FLEXPM_BASE $BACKUP_DIR
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      exit 2
    fi


    ###### module installation customerize here...

    cd $LuUTRAN_HOME/peik/xml

    # remove the dummy LubInterface.xml (we need the dummy LubInterface.xml for Backup original file purpose only
    if [[ -f LubInterface.xml ]]; then
       rm -fr LubInterface.xml
    fi

    touch parser.err
    chmod 777 parser.err

    echo "### running dict_update ###" 
    cd $LuUTRAN_HOME/peik
    make dict_update
    ret=$?
    ret=0

    if [ $ret != 0 ]; then
      echo "+++ Error in make dict_update"
      exit 2
    fi

       echo "### completed dict_update ###"

       ### valnt00061827 : Generate report with external fields caused ORA error
       echo "+ running update_metadata.sql..."
       echo "@${WorkDir}/update_metadata.sql" | sqlplus -s ${DB_CONNECT}
       echo " update_metadata.sql done."	

       echo "+ running change_datatype.sql, this might takes awhile..."
       echo "@${WorkDir}/change_datatype.sql" | sqlplus -s ${DB_CONNECT}
       echo " change_datatype.sql done."

       ### SEAde64824 : regen scenario query to cater active/complete scenario with new entities
       echo "+ running regen_sce_query.sql..."
       echo "@${WorkDir}/regen_sce_query.sql" | sqlplus -s ${DB_CONNECT}
       echo " regen_sce_query.sql done."

       #recompile all invalid objects (except for views...):
       echo "+ recompiling invalid object(s)..."
       chmod u+x ${WorkDir}/recompile_schema.sh
       ${WorkDir}/recompile_schema.sh

       #and we recompile for invalid views here...
       echo "+ recompiling invalid view(s)..."
       chmod u+x ${WorkDir}/recompile_view.sh
       ${WorkDir}/recompile_view.sh
       echo " recompiled done."

       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/1.3/LuUTRAN_data
       make clean

       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/1.3/scripts
       make clean
       make all

       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/1.3/LuUTRAN_data
       make all

       ### make RNCCN LOADER
       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/1.3/LuUTRAN_loader/RNC_CN
       make all

       ### make RNCIN LOADER
       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/1.3/LuUTRAN_loader/RNCIN
       make all

       ### make WMSCM LOADER
       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/1.3/LuUTRAN_loader/WMScm
       make all

       ### recompile this...
       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/Network
       echo "@wm_validate_fullkey.sql" | sqlplus -s ${DB_CONNECT}
       echo "@wm_Activate_Parent.sql" | sqlplus -s ${DB_CONNECT}

       cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/missingData
       echo "@wm_AvailableData_pkg.sql" | sqlplus -s ${DB_CONNECT}
       echo "@wm_AvailableData_pkgb.sql" | sqlplus -s ${DB_CONNECT}
       make unplug
       make plug

       date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
       echo ""

