#!/bin/ksh
#

########################################################
# set paths and files

MODULE="LuUMTS_CS"
RELEASE="6.0.9.2.0"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarDir=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz


### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################

# Check env settings
 echo "Checking environment....."

  if ! [[ -d ${FLEXPM_HOME} ]]; then
     echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
     exit;
  fi

  if ! [[ -d ${FLEXPM_BASE} ]]; then
     echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
     exit;
  fi

  if [ -z ${DB_CONNECT} ]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit 1;
  fi

  ###### module variable validation
  if ! [[ -d ${LuUMTS_CS_HOME} ]]; then
     echo "Env variable LuUMTS_CS_HOME must be set to appropriate dir before installation."
     exit;
  fi

    #######################################################
    # Installing module...
    #######################################################

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $FLEXPM_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarDir $FLEXPM_BASE $BACKUP_DIR
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      exit 2
    fi

    help_file_dir=$FLEXPM_HOME/vendor/Common/NE/ProductRelease/HelpFiles
    mkdir -p $help_file_dir
    mv $LuUMTS_CS_HOME/PerfDataRef.uue $help_file_dir

    ###### module installation customize here...

    cd $LuUMTS_CS_HOME/peik/xml

    touch parser.err
    chmod 777 parser.err

    echo "### running dict_update ###" 
    cd $LuUMTS_CS_HOME/peik
    make dict_update
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in make dict_update"
      exit 2
    fi

       echo "### completed dict_update ###"

       ### valnt00061827 : Generate report with external fields caused ORA error
       echo "+ running update_metadata.sql..."
       echo "@${WorkDir}/update_metadata.sql" | sqlplus -s ${DB_CONNECT}
       echo " update_metadata.sql done."	

       ### SEAde64824 : regenerate scenario queries to make new entities 
	# appear in existing active/complete scenarios
       echo "+ running regen_sce_query.sql..."
       echo "@${WorkDir}/regen_sce_query.sql" | sqlplus -s ${DB_CONNECT}
       echo " regen_sce_query.sql done."

       #recompile all invalid objects (except for views...):
       echo "+ recompiling any invalid object(s)..."
       chmod u+x ${WorkDir}/recompile_schema.sh
       ${WorkDir}/recompile_schema.sh

       #and we recompile for invalid views here...
       echo "+ recompiling any invalid view(s)..."
       chmod u+x ${WorkDir}/recompile_view.sh
       ${WorkDir}/recompile_view.sh
       echo " recompilation done."

       ### update CallServer loader
       cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/1.3/LuUMTS_CS_loader/CallServer0302_pm/config
       make dict_update

       ### Rebuild sentry and commander config to include M5 files
       cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/1.3/LuUMTS_CS_data
       make unplug && make plug

       ### create new ftpIN directories for M5 and update makeSentry and makeArg
       cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/1.3/scripts
       make setMod && make unplug && make reset_x && make makedir && make plug

       ### Rebuild Sentry.txt and Argument.txt so that Sentry will pick up CallServer
       ### files in ftpIN/CallServerM5/in
       cd $PROSPECT_HOME/data
       $PROSPECT_HOME/scripts/makeArg $PROSPECT_HOME/element_list > $PROSPECT_HOME/data/Argument.txt

       if [ -a Sentry.txt ]
	then
	mv Sentry.txt Sentry.txt.bak
       fi
       $PROSPECT_HOME/scripts/makeSentry $PROSPECT_HOME/element_list > Sentry.txt

       ### recompile this...
       cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/Network
       echo "@wm_validate_fullkey.sql" | sqlplus -s ${DB_CONNECT}
       echo "@wm_Activate_Parent.sql" | sqlplus -s ${DB_CONNECT}
       echo "@wm_cs_sm_find_instance_pkgb.sql" | sqlplus -s $DB_CONNECT

       date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
       echo ""

