CREATE OR REPLACE PROCEDURE ext_add_shadow_tables( p_table_name IN VARCHAR2) IS
   l_table_id INTEGER;

   -- DSM, DXS and DXC names
   l_dsm_name VARCHAR2(30);
   l_dxs_name VARCHAR2(30);
   l_dxc_name VARCHAR2(30);
BEGIN

   -- Do we have a DXS table?
   BEGIN

      SELECT object_name INTO l_dxs_name
      FROM user_objects
      WHERE object_name = summarize.GenDestName( p_table_name, 'XS' )
      AND object_type = 'TABLE'
      AND subobject_name IS NULL;

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         l_dxs_name := NULL;
   END;


   -- If we found a DXS then we must have a DXC because they
   -- are created in pairs...
   IF ( l_dxs_name IS NOT NULL ) THEN

      -- Load the DSM and DXC names
      l_dsm_name := summarize.GenDestName( p_table_name, 'D' );
      l_dxc_name := summarize.GenDestName( p_table_name, 'XC' );

      --
      -- DXS
      --

      -- Now add table to part_tables using DSM info as a guide
      SELECT part_table_seq.NEXTVAL INTO l_table_id FROM DUAL;

      INSERT INTO part_tables (
         part_table_id, table_name, tablespace_name, period,
         run_hourly, run_daily, run_weekly, run_monthly,
         needs_export, needs_analyze, needs_move, needs_purge,
         future_part, past_part,
         add_sproc, drop_sproc, pre_drop_sproc,
         datatypeid, stat_mask, creation_date )
      SELECT
         l_table_id, l_dxs_name, tablespace_name, period,
         run_hourly, run_daily, run_weekly, run_monthly,
         needs_export, needs_analyze, needs_move, needs_purge,
         future_part, past_part,
         NULL, NULL, NULL,
         datatypeid, stat_mask, wm_date.trunc_to_last_period(sysdate, 'W') 
      FROM part_tables
      WHERE table_name = l_dsm_name;
 
       -- subclass_map
       INSERT INTO subclass_map ( subclass_id, object_id )
       SELECT subclass_id, l_table_id
       FROM part_tables pt, subclass_map sc
       WHERE pt.table_name = l_dsm_name
          AND pt.part_table_id = sc.object_id;
 
      --
      -- DXC
      --

      -- Now add table to part_tables using DSM info as a guide
      SELECT part_table_seq.NEXTVAL INTO l_table_id FROM DUAL;

      INSERT INTO part_tables (
         part_table_id, table_name, tablespace_name, period,
         run_hourly, run_daily, run_weekly, run_monthly,
         needs_export, needs_analyze, needs_move, needs_purge,
         future_part, past_part,
         add_sproc, drop_sproc, pre_drop_sproc,
         datatypeid, stat_mask, creation_date )
      SELECT
         l_table_id, l_dxc_name, tablespace_name, period,
         run_hourly, run_daily, run_weekly, run_monthly,
         needs_export, needs_analyze, needs_move, needs_purge,
         future_part, past_part,
         NULL, NULL, NULL,
         datatypeid, stat_mask, wm_date.trunc_to_last_period(sysdate, 'W')
      FROM part_tables
      WHERE table_name = l_dsm_name;

       -- subclass_map
       INSERT INTO subclass_map ( subclass_id, object_id )
       SELECT subclass_id, l_table_id
       FROM part_tables pt, subclass_map sc
       WHERE pt.table_name = l_dsm_name
          AND pt.part_table_id = sc.object_id;

   END IF;

END ext_add_shadow_tables;
/
show errors
exit
